@@ -9,9 +9,9 @@ A quick test. Won't be able to run it till you change INKSCAPE to the correct pa
 your system.
 """
 
-from svg_ultralight.query import map_ids_to_bounding_boxes, BoundingBox
-from svg_ultralight.constructors import new_sub_element
 from svg_ultralight import new_svg_root
+from svg_ultralight.constructors import new_sub_element
+from svg_ultralight.query import BoundingBox, map_ids_to_bounding_boxes
 
 INKSCAPE = "C:\\Program Files\\Inkscape\\inkscape"
 
@@ -22,9 +22,9 @@ class TestMapIdsToBoundingBoxes:
         Run with a temporary file.
         """
         expected = {
-            "svg1": BoundingBox(x=-9.8, y=-10.0, width=16.0, height=32.0),
-            "rect1": BoundingBox(x=-9.8, y=-10.0, width=16.0, height=9.0),
-            "rect2": BoundingBox(x=-9.8, y=-10.0, width=8.0, height=32.0),
+            "svg1": BoundingBox(x=-10.0, y=-20.0, width=16.0, height=32.0),
+            "rect1": BoundingBox(x=-10.0, y=-20.0, width=16.0, height=9.0),
+            "rect2": BoundingBox(x=-10.0, y=-20.0, width=8.0, height=32.0),
         }
         xml = new_svg_root(10, 20, 160, 19, id="svg1")
         new_sub_element(xml, "rect", id="rect1", x=0, y=0, width=16, height=9)
